com.github.rssh.appcontext.AppContextAsyncProviderLookup
See theAppContextAsyncProviderLookup companion object
AppContextAsyncProviderLookup is a helper trait used by InAppContext to search for async providers with correct priority:
- AppContextAsyncProviders in enclosing scope (highest)
- Local AppContextProvider (sync) converted via fromSyncProvider
- AppContextAsyncProvider[F, T] defined in T's companion object (lowest)
This works because implicit search looks in the companion of the result type (T), but AppContextAsyncProviderLookup[F, T]'s companion is AppContextAsyncProviderLookup, not T. So givens defined here have priority over T's companion.
Attributes
- Companion
- object
- Graph
-
- Supertypes
-
class Objecttrait Matchableclass Any
Members list
In this article