com.github.rssh.appcontext.AppContextAsyncProviders
See theAppContextAsyncProviders companion trait
object AppContextAsyncProviders
Attributes
- Companion
- trait
- Graph
-
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
Members list
Type members
Classlikes
Attributes
- Supertypes
-
class Objecttrait Matchableclass Any
- Known subtypes
-
case class TryBuildFailure[F[_], Xs <: NonEmptyTuple](message: String) extends TryBuild[F, Xs]
Attributes
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass AnyShow all
case class TryBuildSuccess[F[_], Xs <: NonEmptyTuple](providers: AppContextAsyncProviders[F, Xs]) extends TryBuild[F, Xs]
Attributes
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass AnyShow all
Value members
Concrete methods
def of[F[_], T <: NonEmptyTuple](values: T)(using pure: AppContextPure[F]): AppContextAsyncProviders[F, T]
Accept a tuple of services and create an AppContextAsyncProviders for them. The services are wrapped in pure effect.
Accept a tuple of services and create an AppContextAsyncProviders for them. The services are wrapped in pure effect.
given pure: AppContextPure[F] = ...
val providers = AppContextAsyncProviders.of[F, (Service1, Service2)](service1, service2)
val depended = new Dependent(using providers)
Attributes
def tryBuildImpl[F[_] : Type, Xs <: NonEmptyTuple : Type](implicit evidence$1: Type[F], evidence$2: Type[Xs], Quotes): Expr[TryBuild[F, Xs]]
Givens
Givens
inline given build[F[_] : CpsMonad, Xs <: NonEmptyTuple, R <: TryBuild[F, Xs]](implicit evidence$1: CpsMonad[F], inline trb: R, inline ev: R <:< TryBuildSuccess[F, Xs]): AppContextAsyncProviders[F, Xs]
In this article